package com.project.zcustom.service.service.smart;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;

import com.project.zcustom.controller.core.PageParamVo;
import com.project.zcustom.domain.smart.PlatGreenSmart;

import java.util.List;
import java.util.Map;

/**
 * 绿智食堂Service接口
 *
 * @author change
 * @date 2024-10-31
 */
public interface IPlatGreenSmartService extends IService<PlatGreenSmart> {

    /**
     * 分页查询绿智食堂列表
     *
     * @param platGreenSmart 绿智食堂
     * @return 绿智食堂集合
     */
    public IPage<PlatGreenSmart> pagingPlatGreenSmartList(PlatGreenSmart platGreenSmart);

    /**
     * 分页查询绿智食堂列表
     *
     * @param lqw
     * @return 绿智食堂集合
     */
    public IPage<PlatGreenSmart> pagingPlatGreenSmartList(PageParamVo pageParamVo, LambdaQueryWrapper<PlatGreenSmart> lqw);

    /**
     * 查询绿智食堂列表
     *
     * @param platGreenSmart 绿智食堂
     * @return 绿智食堂集合
     */
    public List<PlatGreenSmart> selectPlatGreenSmartList(PlatGreenSmart platGreenSmart);

    /**
     * 查询绿智食堂列表
     *
     * @param platGreenSmart 绿智食堂
     * @return 绿智食堂集合
     */
    public List<PlatGreenSmart> selectPlatGreenSmartList(PlatGreenSmart platGreenSmart,Long limitNum);

    /**
     * 根据指定字段查询信息
     *
     * @param field 字段名称
     * @param filedValue 字段值
     * @return 绿智食堂
     */
    public PlatGreenSmart getPlatGreenSmartByField(String field, String filedValue);

    /**
     * 根据指定字段查询信息
     *
     * @param field      字段名称
     * @param filedValue 字段值
     * @return 绿智食堂
     */
    public PlatGreenSmart getPlatGreenSmartByField(String field, String filedValue, String fieldString);

    /**
     * 根据指定字段查询信息列表
     *
     * @param field 字段名称
     * @param filedValue 字段值
     * @return 绿智食堂
     */
    public List<PlatGreenSmart> selectPlatGreenSmartListByField(String field, String filedValue);

    /**
     * 根据指定字段查询信息列表
     *
     * @param field 字段名称
     * @param filedValue 字段值
     * @return 绿智食堂
     */
    public List<PlatGreenSmart> selectPlatGreenSmartListByField(String field, String filedValue,Long limitNum);

    /**
     *判断指定字段值是否存在
     *
     * @param field 字段名称
     * @param filedValue 字段值
     */
    public void checkFieldExist(String field, String filedValue,String tips,Long id);

    /**
     *  真删接口
     */
    public void reallyDeletePlatGreenSmart(LambdaQueryWrapper<PlatGreenSmart> lqw);

    /**
     * 添加智慧食堂数据
     */
    public void addPlatGreenSmart(String appOrg, Map<String, Object> mapField);

    /**
     * 获取食堂概览
     * @param appOrg
     * @return
     */
    public Map<String, Object> getCanteenData(String appOrg);

    /**
     * 食堂服务满意度
     * @param appOrg
     * @return
     */
    public Map<String, Object> getCanteenScoreData(String appOrg);

    /**
     * 食堂服务满意度排行
     * @param appOrg
     * @return
     */
    public Map<String, Object> getCanteenDegreeData(String appOrg);

    /**
     * 食堂服务人员情况
     * @param appOrg
     * @return
     */
    public List<Map<String, Object>> getCanteenStaff(String appOrg);

    /**
     * 各单位统计排行
     * @param appOrg
     * @return
     */
    public Map<String, Object> getCanteenTotalRank(String appOrg);

    /**
     * 资质证件
     */
    public Map<String, Object> getQualificationData(String appOrg,String canteenName);

    /**
     * 获取食堂名称
     * @param appOrg
     * @return
     */
    List<PlatGreenSmart> getgreenSmartName(String appOrg);
}
